/* Copyright (c) 2010. The SimGrid Team.
 * All rights reserved.                                                     */

/* This program is free software; you can redistribute it and/or modify it
 * under the terms of the license (GNU LGPL) which comes with this package. */

#include <semaphore.h>

int main(void)
{
  sem_t s;
  if (sem_init(&s, 0, 0) != 0) 
     return 1;
  return 0;
}
